@@ -1,20 +1,20 @@
 from abc import ABC, abstractmethod
+from typing import TYPE_CHECKING
 
 from fastapi import APIRouter, FastAPI
 
 from ingenious.core.structured_logging import get_logger
-from ingenious.dependencies import get_chat_history_repository
-from ingenious.models.config import Config
+
+if TYPE_CHECKING:
+    from ingenious.config.main_settings import IngeniousSettings
 
 
 class IApiRoutes(ABC):
-    def __init__(self, config: Config, app: FastAPI):
+    def __init__(self, config: "IngeniousSettings", app: FastAPI):
         self.config = config
         self.logger = get_logger(__name__)
         self.app = app
-        # Note: security_service should be obtained via dependency injection in route handlers
-        # self.security_service = get_security_service(HTTPBasicCredentials)
-        self.chat_history_repository = get_chat_history_repository()
+        # Note: repositories and services should be obtained via dependency injection in route handlers
 
     @abstractmethod
     def add_custom_routes(self) -> APIRouter:
